Page 109 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 109

Home

    were closed, and U. S. ships were ordered to sail into
    war zones and, in some cases, to depth-charge German

    rad

    Japan was also provoked. The Secretary of War,
    Henry Stimson, (a CFR member) met with Roosevelt to
    discuss how to get Japan to make the first overt move to
    start a war with the United States. As a result, a trade

    embargo against Japan was enacted, Japan's assets in the
    U. S. were frozen, and the Panama Canal was closed to
    its ships. In addition, an ultimatum was sent to Japan
    setting conditions in order for trade to resume. Eleven
    days later the Japanese attacked Pearl Harbor leaving
    over two thousand Americans dead and eighteen naval
    vessels sunk or damaged. War in the Pacific had begun.

    It is now well documented that Roosevelt and George

    owes

    Marshall knew ahead of time that the Japanese were
    going to attack, but kept this information from the
    commanders at Pearl Harbor. An authoritative book on

    this subject is John Toland's Infamy: Pearl Harbor and
    Its Aftermath.

    like World War I, left millions of French, German,
    British, and American soldiers dead? The Soviet Union
    greatly expanded its territory, fortunes were made by
    international business cartels, and the world was moved

    closer to a one world government.
    Presidents Roosevelt's closest advisor during the war
    was Harry Hopkins, a zealous admirer of the Bolsheviks.

    104

    The Secret Side of History

    millions of rounds of ammunition. All German consulates

    U-boats.

    And what was the aftermath of World War II that,